@@ -7,16 +7,16 @@ from functools import partial
 import os
 import logging
 
-VERSION = '1.0'
-
-"""Inspired by Jose Nazario's PHP sandbox, extended/modified by Lukas Rist"""
+# Inspired by Jose Nazario's PHP sandbox, extended/modified by Lukas Rist
 
 logger = logging.getLogger(__name__)
 
+
 def killer(proc, secs):
     time.sleep(secs)
     try:
-        proc.kill()
+        if proc:
+            proc.kill()
     except OSError:
         pass
 
@@ -47,4 +47,4 @@ def sandbox(script, secs, data_dir):
 
 def run(script, data_dir):
     secs = 10
-    return sandbox(script, secs, data_dir)
\ No newline at end of file
+    return sandbox(script, secs, data_dir)
